LoaderInstruction

Enum LoaderInstruction 

pub enum LoaderInstruction {
    Write {
        offset: u32,
        bytes: Vec<u8>,
    },
    Finalize,
}

Variants



Write

Write program data into an account

Account references

  1. [WRITE, SIGNER] Account to write to

Fields

offset: u32

Offset at which to write the given bytes

bytes: Vec<u8>

Serialized program data



Finalize

Finalize an account loaded with program data for execution

The exact preparation steps is loader specific but on success the loader must set the executable bit of the account.

Account references

  1. [WRITE, SIGNER] The account to prepare for execution
  2. [] Rent sysvar